@@ -22,7 +22,8 @@ except:
 from .extra_mimetypes import guess_all_extensions
 
 FILE_COMMAND = "file"
-MAGIC_CONTENT_LENGTH = 1024*64
+MAGIC_CONTENT_BUFFER = 1024*128
+MAGIC_CONTENT_LENGTH = 1024*1024*64
 MIMETYPE_FOR_TEXT = "text/plain"
 MIMETYPE_FOR_BINARY = "application/octet-stream"
 PRIORITY_EXTS = [
@@ -62,7 +63,7 @@ def set_file_command(cmd):
 
 def get_mimetype_simple_by_stream(stream, filename=None):
     with SafeStreamReader(stream) as stream:
-        data = stream.read(MAGIC_CONTENT_LENGTH)
+        data = stream.read(MAGIC_CONTENT_BUFFER)
         if is_binary_string(data):
             return MIMETYPE_FOR_BINARY
         else:
@@ -71,29 +72,45 @@ def get_mimetype_simple_by_stream(stream, filename=None):
 
 def get_mimetype_simple_by_filename(filename):
     with open(filename, "rb") as fobj:
-        data = fobj.read(MAGIC_CONTENT_LENGTH)
+        data = fobj.read(MAGIC_CONTENT_BUFFER)
         if is_binary_string(data):
             return MIMETYPE_FOR_BINARY
         else:
             return MIMETYPE_FOR_TEXT
 
 
-def get_mimetype_using_file_command_by_stream(stream, filename=None):
+def get_mimetype_using_file_command_by_stream(stream, filename=None, magic_content_length=MAGIC_CONTENT_LENGTH):
     with SafeStreamReader(stream) as stream:
-        content = stream.read(MAGIC_CONTENT_LENGTH)
         proc = subprocess.Popen(
-            [FILE_COMMAND, "--mime-type", "-"],
+            [FILE_COMMAND, "--mime-type", "--parameter", "bytes={}".format(magic_content_length), "-"],
             stdin=subprocess.PIPE,
             stdout=subprocess.PIPE,
             universal_newlines=True,
             )
-        proc.stdin.buffer.write(content)
-        proc.stdin.buffer.close()
+        read_length = 0
+        while True:
+            content = stream.read(MAGIC_CONTENT_BUFFER)
+            if not content:
+                break
+            try:
+                proc.stdin.buffer.write(content)
+            except:
+                break
+            read_length += len(content)
+            if read_length > magic_content_length:
+                break
+        try:
+            proc.stdin.buffer.close()
+        except:
+            pass
         proc.wait(1)
         output = proc.stdout.readlines()
         if output:
-            return output[0].split(":")[1].strip()
-        return get_mimetype_simple_by_stream(stream, filename=filename)
+            try:
+                return output[0].split(":")[1].strip()
+            except:
+                pass
+        return None
 
 
 def get_mimetype_using_file_command_by_filename(filename):
@@ -105,14 +122,16 @@ def get_mimetype_using_file_command_by_filename(filename):
     proc.wait(1)
     output = proc.stdout.readlines()
     if output:
-        return output[0].split(":")[1].strip()
+        try:
+            return output[0].split(":")[1].strip()
+        except:
+            pass
     return get_mimetype_simple_by_filename(filename)
 
 
 def get_mimetype_using_magic_by_stream(stream, filename=None):
     with SafeStreamReader(stream) as stream:
-        content = stream.read(MAGIC_CONTENT_LENGTH)
-        result = magic.detect_from_content(content)
+        result = magic.detect_from_fobj(stream)
         if result:
             return result.mime_type
         else:
@@ -125,7 +144,17 @@ def get_mimetype_using_magic_by_filename(filename):
     else:
         return None
 
+
 def _get_best_mimetype_from_puremagic_result(guessed_types, ext):
+    mimetype = __get_best_mimetype_from_puremagic_result(guessed_types, ext)
+
+    # hack for .fla files
+    if mimetype == "application/msword" and ext == ".fla":
+        return "application/CDFV2"
+
+    return mimetype
+
+def __get_best_mimetype_from_puremagic_result(guessed_types, ext):
     if not guessed_types:
         return None
 
@@ -137,9 +166,10 @@ def _get_best_mimetype_from_puremagic_result(guessed_types, ext):
                     mimetype = guessed_type.mime_type
                     break
                 else:
-                    mimetype = get_mimetype_by_extension(guessed_type.extension)
-                    if mimetype:
-                        break
+                    if guessed_type:
+                        mimetype = get_mimetype_by_extension(guessed_type.extension)
+                        if mimetype:
+                            break
 
     if not mimetype:
         for guessed_type in guessed_types:
@@ -148,9 +178,10 @@ def _get_best_mimetype_from_puremagic_result(guessed_types, ext):
                     mimetype = guessed_type.mime_type
                     break
                 else:
-                    mimetype = get_mimetype_by_extension(guessed_type.extension)
-                    if mimetype:
-                        break
+                    if guessed_type.extension:
+                        mimetype = get_mimetype_by_extension(guessed_type.extension)
+                        if mimetype:
+                            break
     
     if not mimetype:
         for guessed_type in guessed_types:
@@ -159,38 +190,56 @@ def _get_best_mimetype_from_puremagic_result(guessed_types, ext):
                     mimetype = guessed_type.mime_type
                     break
                 else:
-                    mimetype = get_mimetype_by_extension(guessed_type.extension)
-                    break
+                    if guessed_type.extension:
+                        mimetype = get_mimetype_by_extension(guessed_type.extension)
+                        if mimetype:
+                            break
     
     if not mimetype:
         if guessed_types[0].mime_type:
             mimetype = guessed_types[0].mime_type
         else:
-            mimetype = guessed_types[0].mime_type
+            if guessed_types[0].extension:
+                mimetype = get_mimetype_by_extension(guessed_types[0].extension)
+
+    # hack for .pcap files
+    if not mimetype:
+        info = guessed_types[0]
+        if "libpcap" in info.name or "winpcap" in info.name:
+            mimetype = "application/vnd.tcpdump.pcap"
 
     return mimetype
 
 
 
-def get_mimetype_using_puremagic_by_stream(stream, filename):
+def get_mimetype_using_puremagic_by_stream(stream, filename, force=True):
+    mimetype = None
     with SafeStreamReader(stream) as stream:
         try:
             guessed_types = puremagic.magic_stream(stream, filename=filename)
             ext = os.path.splitext(filename)[1]
-            return _get_best_mimetype_from_puremagic_result(guessed_types, ext)
+            mimetype = _get_best_mimetype_from_puremagic_result(guessed_types, ext)
         except Exception:
-            return None
+            pass
+    if not mimetype and force:
+        mimetype = get_mimetype_simple_by_stream(stream, filename)
+    return mimetype
 
-def get_mimetype_using_puremagic_by_filename(filename):
+
+def get_mimetype_using_puremagic_by_filename(filename, force=True):
+    mimetype = None
     try:
         guessed_types = puremagic.magic_file(filename)
         ext = os.path.splitext(filename)[1]
-        return _get_best_mimetype_from_puremagic_result(guessed_types, ext)
+        mimetype = _get_best_mimetype_from_puremagic_result(guessed_types, ext)
     except Exception:
-        return None
+        pass
+    if not mimetype and force:
+        mimetype = get_mimetype_by_filename(filename)
+    return mimetype
 
 
-def get_mimetype_by_stream(stream, filename, enable_using_magic=True, enable_using_file_command=True, enable_using_puremagic=True):
+def get_mimetype_by_stream(stream, filename, enable_using_magic=True, enable_using_file_command=True, enable_using_puremagic=True, magic_content_length=MAGIC_CONTENT_LENGTH):
     mimetype = None
     if (not mimetype) and magic and USING_MAGIC and enable_using_magic:
         try:
@@ -199,12 +248,12 @@ def get_mimetype_by_stream(stream, filename, enable_using_magic=True, enable_usi
             logger.warning("get mimetype using magic by stream failed: {error}...".format(error=error))
     if (not mimetype) and USING_FILE_COMMAND and enable_using_file_command:
         try:
-            mimetype = get_mimetype_using_file_command_by_stream(stream, filename)
+            mimetype = get_mimetype_using_file_command_by_stream(stream, filename, magic_content_length)
         except Exception as error:
             logger.warning("get mimetype using file command by stream failed: {error}...".format(error=error))
     if (not mimetype) and USING_PUREMAGIC and enable_using_puremagic:
         try:
-            mimetype = get_mimetype_using_puremagic_by_stream(stream, filename)
+            mimetype = get_mimetype_using_puremagic_by_stream(stream, filename, force=False)
         except Exception as error:
             logger.warning("get mimetype using puremagic by stream failed: {error}...".format(error=error))
     if not mimetype:
@@ -226,7 +275,7 @@ def get_mimetype_by_filename(filename, enable_using_magic=True, enable_using_fil
             logger.warning("get mimetype using file command by filename failed: {error}...".format(error=error))
     if (not mimetype) and USING_PUREMAGIC and enable_using_puremagic:
         try:
-            mimetype = get_mimetype_using_puremagic_by_filename(filename)
+            mimetype = get_mimetype_using_puremagic_by_filename(filename, force=False)
         except Exception as error:
             logger.warning("get mimetype using puremagic by filename failed: {error}...".format(error=error))
     if not mimetype:
@@ -234,7 +283,7 @@ def get_mimetype_by_filename(filename, enable_using_magic=True, enable_using_fil
     return mimetype
 
 
-def is_file_content_matches_with_file_suffix(filename, stream=None, enable_using_magic=True, enable_using_file_command=True, enable_using_puremagic=True):
+def is_file_content_matches_with_file_extension(filename, stream=None, enable_using_magic=True, enable_using_file_command=True, enable_using_puremagic=True):
     if stream:
         mimetype = get_mimetype_by_stream(stream, filename=filename, enable_using_magic=enable_using_magic, enable_using_file_command=enable_using_file_command, enable_using_puremagic=enable_using_puremagic)
     else:
@@ -245,3 +294,5 @@ def is_file_content_matches_with_file_suffix(filename, stream=None, enable_using
         return True
     else:
         return False
+
+is_file_content_matches_with_file_suffix = is_file_content_matches_with_file_extension
\ No newline at end of file
